package cornell.ece4760.timesystem;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.CheckBox;

/**
 * This class handles all the Dialogs needed in the routine
 * configuration feature. Different UI is loaded based on 
 * the InstID added by the calling method.
 * 
 * @author Andy Liang
 */
public class DialogActivity extends Activity {
	private static final String TAG= "DialogActivity";
	private int InstID;
	private int Seq;
	private NumberPicker picker;
	private Button addButton;
	private CheckBox displayCheck;
	private CheckBox innerCheck;
	private Button upButton;
	private Button downButton;
	private Button deleteButton;
	
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		Log.e(TAG, "+++ ON CREATE +++");
		
		InstID= getIntent().getExtras().getInt("InstID");
		
		switch(InstID) {
		case 9: //loop
			this.setTitle("Loop setup");
			setContentView(R.layout.dialog_loop);
			 picker = (NumberPicker) findViewById(R.id.loop_picker);
			 picker.setRange(1, 32);
			 picker.setCurrent(1);
			 addButton= (Button) findViewById(R.id.loop_ok);
			 displayCheck= (CheckBox) findViewById(R.id.loop_display);
			 innerCheck= (CheckBox) findViewById(R.id.loop_inner);
			 addButton.setOnClickListener(new OnClickListener() {
		            public void onClick(View v) {
		           		// pass selected value back
		            	loopDone();
		            }
		     });
			break;
		case 1: //jump
			this.setTitle("Jump to which routine?");
			setContentView(R.layout.dialog_jump);
			 picker = (NumberPicker) findViewById(R.id.jump_picker);
			 picker.setRange(1, 32);
			 picker.setCurrent(1);
			 addButton= (Button) findViewById(R.id.jump_ok);
			 addButton.setOnClickListener(new OnClickListener() {
		            public void onClick(View v) {
		           		// pass selected value back
		            	jumpDone();
		            }
		     });
			break;
		case 5: //routine config edit
			this.setTitle("Edit routine order");
			setContentView(R.layout.dialog_config);
			Seq= getIntent().getExtras().getInt("Seq");
			upButton= (Button) findViewById(R.id.config_up);
			upButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					// pass selected value back
					Intent resultIntent = new Intent();
					resultIntent.putExtra("Direction", 1);
					resultIntent.putExtra("Seq", Seq);
					setResult(Activity.RESULT_OK, resultIntent);
					finish();
				}
			});
			downButton= (Button) findViewById(R.id.config_down);
			downButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					// pass selected value back
					Intent resultIntent = new Intent();
					resultIntent.putExtra("Direction", 2);
					resultIntent.putExtra("Seq", Seq);
					setResult(Activity.RESULT_OK, resultIntent);
					finish();
				}
			});
			deleteButton= (Button) findViewById(R.id.config_delete);
			deleteButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					// pass selected value back
					Intent resultIntent = new Intent();
					resultIntent.putExtra("Direction", 3);
					resultIntent.putExtra("Seq", Seq);
					setResult(Activity.RESULT_OK, resultIntent);
					finish();
				}
			});
			 
			break;
		default:
			break;
		}
		

	}
	
	private void jumpDone() {
		Intent resultIntent = new Intent();
    	resultIntent.putExtra("RoutineID", picker.getCurrent());
    	setResult(Activity.RESULT_OK, resultIntent);
    	finish();
	}
	
	private void loopDone() {
		Intent resultIntent = new Intent();
    	resultIntent.putExtra("Loops", picker.getCurrent());
    	resultIntent.putExtra("Display", displayCheck.isChecked());
    	resultIntent.putExtra("Inner", innerCheck.isChecked());
    	setResult(Activity.RESULT_OK, resultIntent);
    	finish();
	}

}
