package cornell.ece4760.timesystem;

import java.util.ArrayList;


import android.app.ListActivity;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

/**
 * The Routine Config tab activity displays the list of 32 
 * configurable routines and implements onitemselected for 
 * each routine.
 * 
 * @author Andy Liang
 */
public class Routine extends ListActivity {
	
	private static final String TAG= "Routine";
	private SQLiteDatabase database= null;
	private final String dbName= "RoutineDB";
	private final String tableName= "RoutineContent";
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        ArrayList<String> routines= new ArrayList<String>();
        for (int i= 1; i<=32; i++) {
        	String r= String.format("Routine %d", i);
        	routines.add(r);
        }
		
		this.setListAdapter(new ArrayAdapter<String>(this,
				android.R.layout.simple_list_item_1, routines));
		
		// Initiate/get SQLite database
		database= this.openOrCreateDatabase(dbName, MODE_PRIVATE, null);
		try {
			database.execSQL("CREATE TABLE IF NOT EXISTS " +
							tableName +
							" (RoutineID INT(2), Seq INT(10), Byte1 INT(10), Byte2 INT(10), Label VARCHAR, Message VARCHAR);");
		} catch (SQLException e) {
			Log.e(TAG,e.toString());
		}
		database.close();
		
    }
    
    @Override
    public void onStart() {
        super.onStart();
        Log.e(TAG, "++ ON START ++");
    }
    
    @Override
    public void onStop() {
        super.onStart();
        Log.e(TAG, "++ ON START ++");
    }
    
    // method gets called when list item tapped
    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) {
     // TODO Auto-generated method stub
    	// Check if routine is empty in database, if no row, then create Seq=0 header
    	
    	database= this.openOrCreateDatabase(dbName, MODE_PRIVATE, null);
    	
    	String pos= String.format("%d",position+1);
    	Cursor c = database.rawQuery("SELECT * FROM " +
    			tableName +
    			" WHERE RoutineID = " + pos, null);
    	
    	if (c.getCount() == 0) {
    		ContentValues updateRoutine = new ContentValues();
    	       updateRoutine.put("RoutineID", position+1);
    	       updateRoutine.put("Seq", 0);
    	       updateRoutine.put("Byte1", 128);
    	       updateRoutine.put("Byte2", 0);
    	       updateRoutine.put("Label", "Routine " + ((Integer)(position+1)).toString());
    	       updateRoutine.put("Message", "");
    	       try {
    	    	   long rowID = database.insertOrThrow(tableName, null, updateRoutine);
    	    	   String s= String.format("Inserted rowId:%d",rowID);
    	    	   Log.e(TAG,s);
    	       } catch (SQLException e) {
    	    	   String error= String.format("Error: %s", e.toString());
    	    	   Toast.makeText(this, error, Toast.LENGTH_SHORT).show();
    	    	   Log.e(TAG,error);
    	       }
    	} else {
    		Log.e(TAG,c.toString());
    	}
    	c.close();
    	database.close();
    	
    	
     String selection = l.getItemAtPosition(position).toString();
     Toast.makeText(this, selection, Toast.LENGTH_SHORT).show();
     Intent serverIntent = new Intent(this, RoutineConfig.class);
     serverIntent.putExtra("RoutineID", position+1);
     startActivityForResult(serverIntent, 1);
    }
    
}