package cornell.ece4760.timesystem;

import android.app.Activity;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.Toast;

/**
 * This class is responsible for handling addition of timing events.
 * @author Andy Liang
 *
 */

public class Timing extends Activity {

    private static final String TAG = "Timing";
    private static final boolean D = true;
    private NumberPicker pickerMin= null;
    private NumberPicker pickerSec= null;
    private RadioButton countup= null;
    private RadioButton countdown= null;
    private EditText message;
    private Button mAddButton= null;
    private int RoutineID= 0;
    private int Seq= 0;
    private int Min= 0;
    private int Sec= 0;
    private boolean UD= true;
    private String Message= "";
    
    
    private SQLiteDatabase database= null;
	private final String dbName= "RoutineDB";
	private final String tableName= "RoutineContent";

	 @Override
	    public void onCreate(Bundle savedInstanceState) {
	        super.onCreate(savedInstanceState);
	        if(D) Log.e(TAG, "+++ ON CREATE +++");

	        // Set up the window layout
	        setContentView(R.layout.timing);
	       RoutineID= getIntent().getExtras().getInt("RoutineID");
	       Seq = getIntent().getExtras().getInt("Seq");
	       message= (EditText) findViewById(R.id.timing_message);
	       
	       if (Seq > 0) {
	    	   Min= getIntent().getExtras().getInt("Min");
	    	   Sec= getIntent().getExtras().getInt("Sec");
	    	   UD= getIntent().getExtras().getBoolean("UD");
	    	   Message= getIntent().getExtras().getString("Message");
		       CharSequence cs= Message;
		       message.setText(cs);
	    	   
	       }
	       pickerMin = (NumberPicker) findViewById(R.id.timing_picker_min);
	       pickerMin.setFormatter(NumberPicker.TWO_DIGIT_FORMATTER);
	       pickerMin.setCurrent(Min);
	       pickerSec= (NumberPicker) findViewById(R.id.timing_picker_sec);
	       pickerSec.setFormatter(NumberPicker.TWO_DIGIT_FORMATTER);
	       pickerSec.setCurrent(Sec);
	       countup= (RadioButton) findViewById(R.id.count_up);
	       countup.setChecked(UD);
	       countdown= (RadioButton) findViewById(R.id.count_down);
	       countdown.setChecked(!UD);
	       // Add button code
	       mAddButton = (Button) findViewById(R.id.button_add);
	       mAddButton.setOnClickListener(new OnClickListener() {
	            public void onClick(View v) {
	           		// insert into DB
	           		updateDB();
	            }
	        });
	 }
	 
	 private void updateDB() {
		// prepare the bytes
     	int min = 64+pickerMin.getCurrent();
    		int sec= 64+pickerSec.getCurrent();
    		if (countdown.isChecked()) {
    			min -= 64;
    			sec -= 64;
    		}
    		String byte1= String.format("%d", min);
    		String byte2= String.format("%d", sec);
    		String msg= message.getText().toString();
    		
		// Get database
    	database= this.openOrCreateDatabase(dbName, MODE_PRIVATE, null);
    	// get max Seq
    	int MaxSeq= 0;
    	
    	if (Seq == 0) {
    	String rid= String.format("%d", RoutineID);
    	Cursor c = database.rawQuery("SELECT Seq FROM " +
    			tableName +
    			" WHERE RoutineID = " + rid + " ORDER BY Seq DESC LIMIT 1", null);
        
    	c.moveToFirst();
    	MaxSeq= c.getInt(c.getColumnIndex("Seq"));
    	c.close();
    	} else {
    		database.delete(tableName, "RoutineID=? AND Seq=?",
			          new String[] {((Integer)RoutineID).toString(), ((Integer)Seq).toString()});
    		MaxSeq= Seq-1;
    		Seq= 0;
    	}
    		
    	ContentValues updateRoutine = new ContentValues();
    	updateRoutine.put("RoutineID", RoutineID);
    	updateRoutine.put("Seq", MaxSeq+1);
    	updateRoutine.put("Byte1", byte1);
    	updateRoutine.put("Byte2", byte2);
    	String label= "";
    	if (countup.isChecked()) {
    		label= String.format("\u2191 %02d:%02d", min-64, sec-64);
    	} else {
    		label= String.format("\u2193 %02d:%02d", min, sec);
    	}
    	updateRoutine.put("Label", label);
    	updateRoutine.put("Message", msg);
    	try {
    		long rowID = database.insertOrThrow(tableName, null, updateRoutine);
    		String s= String.format("Inserted rowId:%d",rowID);
    		Log.e(TAG,s);
    	} catch (SQLException e) {
    		String error= String.format("Error: %s", e.toString());
    		Toast.makeText(this, error, Toast.LENGTH_SHORT).show();
    		Log.e(TAG,error);
    	}
    	database.close();
    	finish();
	 }
	 
	 

}
